.. django-imhotep documentation master file, created by
   sphinx-quickstart on Thu Oct 11 14:32:24 2018.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.

Welcome to django-trench documentation!
==========================================

Contents
--------
.. toctree::
   :maxdepth: 2

   introduction
   installation
   settings
   endpoints
   backends
   examples


Indices and tables
------------------

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
